@@ -11,7 +11,7 @@ import wavchunk
 class WavChunkTestCase(unittest.TestCase):
     """Test cases for wavchunk"""
 
-    def test_add_remove_chunk(self):
+    def test_add_remove_chunk(self) -> None:
         """Test adding and removing INFO chunk"""
         # Generate random WAV file with 100 samples
         audio_data = os.urandom(2 * 100)
@@ -26,6 +26,9 @@ class WavChunkTestCase(unittest.TestCase):
 
             wav_bytes = wav_buffer.getvalue()
 
+        with io.BytesIO(wav_bytes[4:8]) as size_file:
+            original_size = wavchunk.read_size(size_file)
+
         # Random data for INFO
         chunk_data = os.urandom(50)
 
@@ -37,8 +40,16 @@ class WavChunkTestCase(unittest.TestCase):
         # Verify chunk data
         with io.BytesIO(out_bytes) as chunked_file:
             actual_data = wavchunk.get_chunk(chunked_file)
+            assert actual_data is not None
             self.assertEqual(chunk_data, actual_data)
 
+        # Verify RIFF size
+        with io.BytesIO(out_bytes[4:8]) as size_file:
+            size_with_chunk = wavchunk.read_size(size_file)
+
+        # 8 for "data" and data size
+        self.assertEqual(size_with_chunk, original_size + len(actual_data) + 8)
+
 
 # -----------------------------------------------------------------------------
 
